==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/HttpSettingsType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p644063_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p831178_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the options for all external HTTP requests made by the server during the execution of the web service operation.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HttpSettingsType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HttpSettingsType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all minOccurs="0">
 *         <element name="headers" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsHeaderType" minOccurs="0"/>
 *         <element name="ssl" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsSSLType" minOccurs="0"/>
 *         <element name="timeout" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsTimeoutType" minOccurs="0"/>
 *       </all>
 *       <attribute name="userAgent" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="followRedirect" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HttpSettingsType", propOrder = {

})
public class HttpSettingsType {

    protected HttpSettingsHeaderType headers;
    protected HttpSettingsSSLType ssl;
    protected HttpSettingsTimeoutType timeout;
    @XmlAttribute(name = "userAgent")
    protected String userAgent;
    @XmlAttribute(name = "followRedirect")
    protected Boolean followRedirect;

    /**
     * Gets the value of the headers property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsHeaderType }
     *     
     */
    public HttpSettingsHeaderType getHeaders() {
        return headers;
    }

    /**
     * Sets the value of the headers property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsHeaderType }
     *     
     */
    public void setHeaders(HttpSettingsHeaderType value) {
        this.headers = value;
    }

    public boolean isSetHeaders() {
        return (this.headers!= null);
    }

    /**
     * Gets the value of the ssl property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsSSLType }
     *     
     */
    public HttpSettingsSSLType getSsl() {
        return ssl;
    }

    /**
     * Sets the value of the ssl property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsSSLType }
     *     
     */
    public void setSsl(HttpSettingsSSLType value) {
        this.ssl = value;
    }

    public boolean isSetSsl() {
        return (this.ssl!= null);
    }

    /**
     * Gets the value of the timeout property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsTimeoutType }
     *     
     */
    public HttpSettingsTimeoutType getTimeout() {
        return timeout;
    }

    /**
     * Sets the value of the timeout property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsTimeoutType }
     *     
     */
    public void setTimeout(HttpSettingsTimeoutType value) {
        this.timeout = value;
    }

    public boolean isSetTimeout() {
        return (this.timeout!= null);
    }

    /**
     * Gets the value of the userAgent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUserAgent() {
        if (userAgent == null) {
            return "";
        } else {
            return userAgent;
        }
    }

    /**
     * Sets the value of the userAgent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUserAgent(String value) {
        this.userAgent = value;
    }

    public boolean isSetUserAgent() {
        return (this.userAgent!= null);
    }

    /**
     * Gets the value of the followRedirect property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFollowRedirect() {
        if (followRedirect == null) {
            return true;
        } else {
            return followRedirect;
        }
    }

    /**
     * Sets the value of the followRedirect property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFollowRedirect(boolean value) {
        this.followRedirect = value;
    }

    public boolean isSetFollowRedirect() {
        return (this.followRedirect!= null);
    }

    public void unsetFollowRedirect() {
        this.followRedirect = null;
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/HttpSettingsType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p689949_="https://jakarta.ee/xml/ns/jaxb" xmlns:p832256_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the options for all external HTTP requests made by the server during the execution of the web service operation.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HttpSettingsType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HttpSettingsType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all minOccurs="0">
 *         <element name="headers" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsHeaderType" minOccurs="0"/>
 *         <element name="ssl" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsSSLType" minOccurs="0"/>
 *         <element name="timeout" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsTimeoutType" minOccurs="0"/>
 *       </all>
 *       <attribute name="userAgent" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="followRedirect" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HttpSettingsType", propOrder = {

})
public class HttpSettingsType {

    protected HttpSettingsHeaderType headers;
    protected HttpSettingsSSLType ssl;
    protected HttpSettingsTimeoutType timeout;
    @XmlAttribute(name = "userAgent")
    protected String userAgent;
    @XmlAttribute(name = "followRedirect")
    protected Boolean followRedirect;

    /**
     * Gets the value of the headers property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsHeaderType }
     *     
     */
    public HttpSettingsHeaderType getHeaders() {
        return headers;
    }

    /**
     * Sets the value of the headers property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsHeaderType }
     *     
     */
    public void setHeaders(HttpSettingsHeaderType value) {
        this.headers = value;
    }

    public boolean isSetHeaders() {
        return (this.headers!= null);
    }

    /**
     * Gets the value of the ssl property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsSSLType }
     *     
     */
    public HttpSettingsSSLType getSsl() {
        return ssl;
    }

    /**
     * Sets the value of the ssl property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsSSLType }
     *     
     */
    public void setSsl(HttpSettingsSSLType value) {
        this.ssl = value;
    }

    public boolean isSetSsl() {
        return (this.ssl!= null);
    }

    /**
     * Gets the value of the timeout property.
     * 
     * @return
     *     possible object is
     *     {@link HttpSettingsTimeoutType }
     *     
     */
    public HttpSettingsTimeoutType getTimeout() {
        return timeout;
    }

    /**
     * Sets the value of the timeout property.
     * 
     * @param value
     *     allowed object is
     *     {@link HttpSettingsTimeoutType }
     *     
     */
    public void setTimeout(HttpSettingsTimeoutType value) {
        this.timeout = value;
    }

    public boolean isSetTimeout() {
        return (this.timeout!= null);
    }

    /**
     * Gets the value of the userAgent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUserAgent() {
        if (userAgent == null) {
            return "";
        } else {
            return userAgent;
        }
    }

    /**
     * Sets the value of the userAgent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUserAgent(String value) {
        this.userAgent = value;
    }

    public boolean isSetUserAgent() {
        return (this.userAgent!= null);
    }

    /**
     * Gets the value of the followRedirect property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFollowRedirect() {
        if (followRedirect == null) {
            return true;
        } else {
            return followRedirect;
        }
    }

    /**
     * Sets the value of the followRedirect property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFollowRedirect(boolean value) {
        this.followRedirect = value;
    }

    public boolean isSetFollowRedirect() {
        return (this.followRedirect!= null);
    }

    public void unsetFollowRedirect() {
        this.followRedirect = null;
    }

}
